@@ -266,43 +266,87 @@ class _Trochoid(ABC):
             cls, R: Union[Number, List[Number]], r: Union[Number, List[Number]],
             d: Union[Number, List[Number]], thetas: List[Number] = None,
             theta_start: Number = None, theta_stop: Number = None,
-            theta_step: Number = None, origin: Tuple[Number, Number] = (0, 0)
+            theta_step: Number = None, origin: Tuple[Number, Number] = (0, 0),
+            screen_size: Tuple[Number, Number] = (1000, 1000),
+            screen_color: str = "white", exit_on_click: bool = False,
+            color: str = "black", width: Number = 1,
+            frame_pause: Number = 0.1, screen: "turtle.Screen" = None
         ) -> List["_Trochoid"]:
-        """Animate the shape where one of the input parameters
-        is a list of increments i.e. R, r, d and the rest are fixed
+        """
+        Animate a sequence of _Trochoid shapes with varying input parameters,
+        drawn one after the other.
 
         Parameters
         ----------
         R : Union[Number, List[Number]]
-            Radius of the fixed circle
+            Radius of the fixed circle.
         r : Union[Number, List[Number]]
-            Radius of the rolling circle
+            Radius of the rolling circle.
         d : Union[Number, List[Number]]
-            Distance of the trace point from the rolling circle
-        thetas : List[Number] = None
+            Distance of the trace point from the rolling circle.
+        thetas : List[Number], optional
             Input list of values for theta for inputting into parametric equations.
             This argument cannot be set at the same time as theta_start,
-            theta_stop, theta_step
-        theta_start : Number = None
+            theta_stop, theta_step.
+        theta_start : Number, optional
             Starting theta value for creating a list of thetas (similar syntax
             to built-in range or np.arange). This argument cannot be set at the
-            same time as thetas argument
-        theta_stop : Number = None
+            same time as thetas argument.
+        theta_stop : Number, optional
             Stop theta value for creating a list of thetas, stop value is not
             included in the final array (similar syntax to built-in range or
             np.arange). This argument cannot be set at the same time as thetas
-            argument
-        theta_step : Number = None
+            argument.
+        theta_step : Number, optional
             Incremental step value for stepping from start to stop
             (similar syntax to built-in range or np.arange). This argument
-            cannot be set at the same time as thetas argument
-        origin : Tuple[Number, Number] = (0, 0)
-            Custom origin to center the shapes at. Default is (0,0)
+            cannot be set at the same time as thetas argument.
+        origin : Tuple[Number, Number], optional, default (0, 0)
+            Custom origin to center the shapes at. Default is (0,0).
+        screen_size : Tuple[Number, Number], optional, default (1000, 1000)
+            Length and width of the output screen.
+        screen_color : str, optional, default "white"
+            Color of the background screen.
+        exit_on_click : bool, optional, default False
+            Pause the final animation until the user clicks to exit the window.
+        color : str, optional, default "black"
+            Color of the primary tracing.
+        width : Number, optional, default 1
+            Width of the turtle tracing.
+        frame_pause : Number, optional, default 0.1
+            Time in seconds to pause between each shape in the animation.
+        screen : turtle.Screen, optional
+            Existing turtle screen.
+
+        Returns
+        -------
+        shapes : List[_Trochoid]
+            A list of instantiated _Trochoid shapes with varying input parameters.
+
+        Examples
+        --------
+        >>> from spyrograph import Hypotrochoid
+        >>> import numpy as np
+        >>> thetas = np.linspace(0, 2 * np.pi, num=1000)
+        >>> shapes = Hypotrochoid.animate(R=10, r=[4, 5, 6], d=8, thetas=thetas)
         """
         shapes_arr = cls.create_range(
             R, r, d, thetas, theta_start,
             theta_stop, theta_step, origin
         )
+        for shape in shapes_arr:
+            if screen is not None:
+                screen.clear()
+                screen.setup(*screen_size)
+                screen.bgcolor(screen_color)
+            screen = shape.trace(
+                screen = screen, screen_size = screen_size,
+                screen_color = screen_color,
+                color = color, width=width
+            )
+            time.sleep(frame_pause)
+        if exit_on_click:
+            turtle.exitonclick()
 
     @property
     def df(self) -> "pd.DataFrame":
@@ -469,7 +513,7 @@ class _Trochoid(ABC):
             self, screen: "turtle.Screen", screen_size: Tuple[Number, Number],
             screen_color: str
         ) -> "turtle.Screen":
-        """Return initialized turtle.Screen"""
+        """Initializes the turtle screen with the given size and color"""
         if screen is None:
             screen = turtle.Screen()
             screen.setup(*screen_size)
